@@ -7,7 +7,7 @@ Business::TrueLayer - Perl library for interacting with the TrueLayer v3 API
 
 =head1 VERSION
 
-v0.02
+v0.03
 
 =head1 SYNOPSIS
 
@@ -40,6 +40,15 @@ v0.02
         ...
     }
 
+    # create a mandate, then create a payment
+    my $Mandate = $TrueLayer->create_mandate( $args );
+
+    if ( $Mandate->authorized ) {
+        my $Payment = $TrueLayer->create_payment_from_mandate(
+            $Mandate,$amount_in_minor_units
+        );
+    }
+
 =head1 DESCRIPTION
 
 L<Business::TrueLayer> is a client library for interacting with the
@@ -64,14 +73,17 @@ use Moose;
 extends 'Business::TrueLayer::Request';
 no warnings qw/ experimental::signatures experimental::postderef /;
 
+use namespace::autoclean;
+
 use Business::TrueLayer::Authenticator;
 use Business::TrueLayer::MerchantAccount;
+use Business::TrueLayer::Mandate;
 use Business::TrueLayer::Payment;
 use Business::TrueLayer::Signer;
 use Business::TrueLayer::Types;
 use Business::TrueLayer::User;
 
-$Business::TrueLayer::VERSION = '0.02';
+$Business::TrueLayer::VERSION = '0.03';
 
 =head1 METHODS
 
@@ -217,6 +229,133 @@ sub get_payment (
     );
 }
 
+=head2 create_mandate
+
+Instantiates a L<Business::TrueLayer::Mandate> object then calls the
+API to create it - will return the object to allow you to inspect it
+and call methods on it.
+
+    my $Mandate = $TrueLayer->create_mandate( $args );
+
+C<$args> should be a hash reference of the necessary attributes to
+instantiate a L<Business::TrueLayer::Mandate> object - see the perldoc
+for that class for the attributes required.
+
+Any issues here will result in an exception being thrown.
+
+=cut
+
+sub create_mandate (
+    $self,
+    $mandate_constuctor_args,
+) {
+    # instantiate an object first to perform type checking before
+    # we send a request to the API
+    Business::TrueLayer::Mandate->new(
+        $mandate_constuctor_args,
+    );
+
+    # send request to the API
+    my $response = $self->api_post(
+        '/v3/mandates',
+        $mandate_constuctor_args,
+    );
+
+    # return a new instance of the Payment object, with the original
+    # args and the details from the response
+    return Business::TrueLayer::Mandate->new({
+        $mandate_constuctor_args->%*,
+
+        $response->%{ qw / id status / },
+
+        host => $self->host,
+        payment_host => $self->payment_host,
+
+        user => Business::TrueLayer::User->new(
+            $mandate_constuctor_args->{user}->%*,
+            id => $response->{user}{id},
+        ),
+    });
+}
+
+=head2 get_mandate
+
+Calls the API to get the details for a mandate for the given id then
+instantiates a L<Business::TrueLayer::Mandate> object for return to
+the caller
+
+    my $Mandate = $TrueLayer->get_mandate( $mandate_id );
+
+Any issues here will result in an exception being thrown.
+
+=cut
+
+sub get_mandate (
+    $self,
+    $mandate_id,
+) {
+    # send request to the API
+    my $response = $self->api_get(
+        '/v3/mandates/' . $mandate_id,
+    );
+
+    return Business::TrueLayer::Mandate->new({
+        $response->%*,
+        host => $self->host,
+        payment_host => $self->payment_host,
+    });
+}
+
+=head2 create_payment_from_mandate
+
+Returns a L<Business::TrueLayer::Payment> object after having called
+the TrueLayer API for a particular mandate
+
+    my $Payment = $TrueLayer->create_payment_from_mandate(
+        $Mandate,
+        $amount_in_minor_units,
+    );
+
+C<$Mandate> should be a Business::TrueLayer::Mandate object, and
+C<$amount_in_minor_units> should be exactly that.
+
+Any issues here will result in an exception being thrown.
+
+=cut
+
+sub create_payment_from_mandate (
+    $self,
+    $Mandate,
+    $amount_in_minor_units,
+) {
+    my %request = (
+        payment_method => {
+            type => 'mandate',
+            mandate_id   => $Mandate->id,
+        },
+        amount_in_minor => $amount_in_minor_units,
+        currency => $Mandate->currency,
+        user => { $Mandate->user->%* },
+    );
+
+    my $response = $self->api_post(
+        '/v3/payments',
+        \%request,
+    );
+
+    return Business::TrueLayer::Payment->new(
+        $response->%{ qw / id status /},
+        %request,
+
+        host => $self->host,
+        payment_host => $self->payment_host,
+        user => Business::TrueLayer::User->new(
+            $request{user}->%*,
+            id => $response->{user}{id},
+        ),
+    );
+}
+
 1;
 
 =head1 SEE ALSO
